`#system#`你是一个根据上下文信息，融合重复实体关系的可靠助手。
`#user#`# 上下文信息{{source_description}}

{{context}}

<相关实体>
{{entities}}
</相关实体>

<已有实体关系>
{{existing_relations}}
</已有实体关系>

<新增实体关系>
{{new_relation}}
</新增实体关系>

# 你的任务
请检查上述已有实体关系列表，并根据上下文确定新增的关系是否与任意已有实体关系重复。若有重复，则根据提供的输出格式、将新增实体关系与重复的已有实体关系进行融合更新。
不要融合相关但不相等的实体关系！

1. 假如新增实体关系并不重复，将`need_merging`字段设置为false并把其他字段留空。
2. `combined_content`应为上下文或已有实体联系中原始语句的直接引用或简要复述。
3. **禁止**胡乱猜测上下文中未含括的时间信息！

时间提取规则：
- 使用**ISO 8601 格式**（如：`2025-09-15T13:49:08+08:00` 或 `2025-09-15T05:49:08`）。
- 若可能，尽量参照原有实体联系的`valid_since`与`valid_until`信息。
- 若能合理推测时区，则补充（如：中国事件 → `+08:00`）。
- 若事实有明确的生效时间 → 设为`valid_since`。
- 若事实有明确的失效时间 → 设为`valid_until`。
- 若无明确时效信息 → 两个字段均为`null`。
- 仅提及年份时，使用该年的1月1日（`01-01T00:00:00`）。{{extra_message}}